@@ -1,5 +1,6 @@
 import logging
 import sys
+from collections import deque
 from os import chdir, path
 
 import click
@@ -97,19 +98,22 @@ def deploy(buildp, mpath, dpath, nomitall, channel, dry_run, skip_confirm):
         raise Exception(
             "There was a problem connecting to the docker agent, ensure it is running and in a good state"
         ) from e
-    image = build_engine(
+    image, tag = build_engine(
         engine_name=engine_name, client=client, tag=channel, docker_file=dpath,
     )
     if not dry_run:
-        deploy_engine(image, data)
+        deploy_engine(image, tag, data)
+        if channel == "stable" and nomitall == "nomitall-prod":
+            deploy_engine(image, "prod", data)
 
 
-def deploy_engine(image, creds):
+def deploy_engine(image, tag, creds):
     _logger.info("----Pushing image----")
     client = docker.from_env()
     auth_config = {"username": creds["user"], "password": creds["token"]}
-    push_logs = client.api.push(image, auth_config=auth_config, stream=True)
-    list(stream_output(push_logs, sys.stdout))
+    _logger.info(f"Pushing {image}:{tag}")
+    push_logs = client.api.push(image, tag=tag, auth_config=auth_config, stream=True)
+    deque(stream_output(push_logs, sys.stdout), maxlen=0)
     _logger.info("----Successfully pushed image----")
 
 
@@ -123,6 +127,6 @@ def build_engine(engine_name, client, tag, docker_file, buildargs=None):
         pull=True,
         buildargs=buildargs,
     )
-    list(stream_output(build_logs, sys.stdout))
+    deque(stream_output(build_logs, sys.stdout), maxlen=0)
     _logger.info("----Finished building image----")
-    return ":".join([engine_name, tag])
+    return engine_name, tag
